<?php

/* 
Name:Steven Price
Date: 6 Nov 2008
Description: Library of functions to access XML data
Updated: 19.12.2008 by Guy Carberry.

How to use..

Add the following code before or inside the html 
<head>
element:

<?php require('dsn/dsn.php'); ?>

(adjust the path according to your site structure.

Next, add the following code where you want to display navigation:

<?php dsn_sections(); ?>
<?php dsn_ancestors(); ?>
<?php dsn_parent_siblings(); ?>
<?php dsn_parent(); ?>
<?php dsn_siblings(); ?>
<?php dsn_children(); ?>
<?php dsn_paged(); ?>
<?php dsn_sitemap(); ?>
<?php dsn_utilities(); ?>
<?php dsn_atoz(); ?>

Additional functions:

<?php dsn_title(); ?>
<?php dsn_keywords(); ?>
<?php dsn_description(); ?>
*/

/* 
Define page 
--------------------------------------------------------------------- */

//Work out the page name
function get_page() {  
   $this_page = basename($_SERVER['SCRIPT_NAME']);    
   return $this_page;
}

/* 
Load processor 
--------------------------------------------------------------------- */

function load_XML($load_xsl) {   
   // work out the page name
   $this_page = get_page();
      
   // load the XML
   $xml = new DOMDocument;
   $xml->load('structure.xml');
   $xsl = new DOMDocument;
   
   // load the XSL
   $xsl->load($load_xsl);
   
   // configure the transformer
   $proc = new XSLTProcessor;
   $proc->setParameter('', 'this_page', $this_page);
   $proc->importStyleSheet($xsl); // attach the xsl rules   
   echo $proc->transformToXML($xml);
}

/* 
Load functions 
--------------------------------------------------------------------- */

// Parent and Siblings
function dsn_parent_siblings() {  
  $load_xsl = 'dsn/parent_siblings.xsl';  
  load_XML($load_xsl);  
}

// Ancestors
function dsn_ancestors() {
  $load_xsl = 'dsn/ancestors.xsl';
  load_XML($load_xsl); 
}

// Children
function dsn_children() {
  $load_xsl = 'dsn/children.xsl';
  load_XML($load_xsl); 
}

// Children-basic
function dsn_children_basic() {
  $load_xsl = 'dsn/children_basic.xsl';
  load_XML($load_xsl); 
}

// Sitemap
function dsn_sitemap() {
  $load_xsl = 'dsn/sitemap.xsl';
  load_XML($load_xsl); 
}

// Ancestors
function dsn_pagetitle() {
  $load_xsl = 'dsn/pagetitle.xsl';
  load_XML($load_xsl); 
}

// Keywords
function dsn_keywords() {
  $load_xsl = 'dsn/keywords.xsl';
  load_XML($load_xsl);   
}
  
// Description
function dsn_description() {
  $load_xsl = 'dsn/description.xsl';
  load_XML($load_xsl);     
}

// Sections
function dsn_sections() {
  $load_xsl = 'dsn/sections.xsl';
  load_XML($load_xsl); 
}

// Utilities
function dsn_utilities() {
  $load_xsl = 'dsn/utilities.xsl';
  load_XML($load_xsl); 
}

// Parent
function dsn_parent() {
  $load_xsl = 'dsn/parent.xsl';
  load_XML($load_xsl); 
}

// Siblings
function dsn_siblings() {
  $load_xsl = 'dsn/siblings.xsl';
  load_XML($load_xsl); 
}

// AtoZ
function dsn_atoz() {
  $load_xsl = 'dsn/atoz.xsl';
  load_XML($load_xsl); 
}

// AtoZ list
function dsn_atoz_list() {
  $load_xsl = 'dsn/atozlist.xsl';
  load_XML($load_xsl); 
}

// Paged
function dsn_paged() {
  $load_xsl = 'dsn/paged.xsl';
  load_XML($load_xsl); 
}

?>